@@ -1,6 +1,7 @@
 package Catalyst::Controller::DBIC::API;
-$Catalyst::Controller::DBIC::API::VERSION = '2.002001';
-$Catalyst::Controller::DBIC::API::VERSION = '2.002001';
+BEGIN {
+  $Catalyst::Controller::DBIC::API::VERSION = '2.002002';
+}
 
 #ABSTRACT: Provides a DBIx::Class web service automagically
 use Moose;
@@ -446,7 +447,7 @@ sub validate_object
             }
 
             # check for multiple values
-            if (ref($value) && !($value == JSON::Any::true || $value == JSON::Any::false))
+            if (ref($value) && !(reftype($value) eq reftype(JSON::Any::true)))
             {
                 require Data::Dumper;
                 die "Multiple values for '${key}': ${\Data::Dumper::Dumper($value)}";
@@ -521,13 +522,22 @@ sub update_object_from_params
     foreach my $key (keys %$params)
     {
         my $value = $params->{$key};
-        if (ref($value) && !($value == JSON::Any::true || $value == JSON::Any::false))
+        if (ref($value) && !(reftype($value) eq reftype(JSON::Any::true)))
         {
             $self->update_object_relation($c, $object, delete $params->{$key}, $key);
         }
+        # accessor = colname
+        elsif ($object->can($key)) {
+            $object->$key($value);
+        }
+        # accessor != colname
+        else {
+            my $accessor = $object->result_source->column_info($key)->{accessor};
+            $object->$accessor($value);
+        }
     }
 
-    $object->update($params);
+    $object->update();
 }
 
 
@@ -537,7 +547,23 @@ sub update_object_relation
     my $row = $object->find_related($relation, {} , {});
 
     if ($row) {
-        $row->update($related_params);
+        foreach my $key (keys %$related_params) {
+            my $value = $related_params->{$key};
+            if (ref($value) && !(reftype($value) eq reftype(JSON::Any::true)))
+            {
+                $self->update_object_relation($c, $row, delete $related_params->{$key}, $key);
+            }
+            # accessor = colname
+            elsif ($row->can($key)) {
+                $row->$key($value);
+            }
+            # accessor != colname
+            else {
+                my $accessor = $row->result_source->column_info($key)->{accessor};
+                $row->$accessor($value);
+            }
+        }
+        $row->update();
     }
     else {
         $object->create_related($relation, $related_params);
@@ -551,7 +577,7 @@ sub insert_object_from_params
 
     my %rels;
     while (my ($k, $v) = each %{ $params }) {
-        if (ref $v && !($v == JSON::Any::true || $v == JSON::Any::false)) {
+        if (ref($v) && !(reftype($v) eq reftype(JSON::Any::true))) {
             $rels{$k} = $v;
         }
         else {
@@ -626,6 +652,7 @@ sub each_object_inflate
     return { $object->get_columns };
 }
 
+
 # from Catalyst::Action::Serialize
 sub serialize :ActionClass('Serialize') { }
 
@@ -655,7 +682,7 @@ Catalyst::Controller::DBIC::API - Provides a DBIx::Class web service automagical
 
 =head1 VERSION
 
-version 2.002001
+version 2.002002
 
 =head1 SYNOPSIS
 
@@ -980,7 +1007,7 @@ save_object first checks to see if the object is already in storage. If so, it c
 
 =head2 update_object_from_params
 
-update_object_from_params iterates through the params to see if any of them are pertinent to relations. If so it calls L</update_object_relation> with the object, and the relation parameters. Then it calls ->upbdate on the object.
+update_object_from_params iterates through the params to see if any of them are pertinent to relations. If so it calls L</update_object_relation> with the object, and the relation parameters. Then it calls ->update on the object.
 
 =head2 update_object_relation
 
@@ -1008,6 +1035,10 @@ each_object_inflate executes during L</end> and allows hooking into the process
 
 This only executes if L</return_object> if set and if there are any objects to actually return.
 
+=head2 serialize
+
+multiple actions forward to serialize which uses Catalyst::Action::Serialize.
+
 =head2 push_error
 
 push_error stores an error message into the stash to be later retrieved by L</end>. Accepts a Dict[message => Str] parameter that defines the error message.
@@ -1074,14 +1105,29 @@ The internals are much easier to read and understand with lots more documentatio
 
 =head1 AUTHORS
 
-  Nicholas Perez <nperez@cpan.org>
-  Luke Saunders <luke.saunders@gmail.com>
-  Alexander Hartmaier <abraxxa@cpan.org>
-  Florian Ragwitz <rafl@debian.org>
+=over 4
+
+=item *
+
+Nicholas Perez <nperez@cpan.org>
+
+=item *
+
+Luke Saunders <luke.saunders@gmail.com>
+
+=item *
+
+Alexander Hartmaier <abraxxa@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Luke Saunders, Nicholas Perez, et al..
+This software is copyright (c) 2010 by Luke Saunders, Nicholas Perez, Alexander Hartmaier, et al..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
