@@ -1,6 +1,7 @@
 package Catalyst::Controller::DBIC::API::RPC;
-$Catalyst::Controller::DBIC::API::RPC::VERSION = '2.002001';
-$Catalyst::Controller::DBIC::API::RPC::VERSION = '2.002001';
+BEGIN {
+  $Catalyst::Controller::DBIC::API::RPC::VERSION = '2.002002';
+}
 #ABSTRACT: Provides an RPC interface to DBIx::Class
 
 use Moose;
@@ -17,6 +18,7 @@ __PACKAGE__->config(
 );
 
 
+
 sub index : Chained('setup') PathPart('') Args(0) {
 	my ( $self, $c ) = @_;
 
@@ -84,7 +86,7 @@ Catalyst::Controller::DBIC::API::RPC - Provides an RPC interface to DBIx::Class
 
 =head1 VERSION
 
-version 2.002001
+version 2.002002
 
 =head1 DESCRIPTION
 
@@ -115,6 +117,14 @@ As described in L<Catalyst::Controller::DBIC::API/setup>, this action is the cha
 	...
   );
 
+=head2 index
+
+Chained: L</setup>
+PathPart: ''
+Args: 0
+
+Returns http status code 404 by default.
+
 =head2 create
 
 Chained: L</objects_no_id>
@@ -173,14 +183,29 @@ Provides an endpoint to the functionality described in L<Catalyst::Controller::D
 
 =head1 AUTHORS
 
-  Nicholas Perez <nperez@cpan.org>
-  Luke Saunders <luke.saunders@gmail.com>
-  Alexander Hartmaier <abraxxa@cpan.org>
-  Florian Ragwitz <rafl@debian.org>
+=over 4
+
+=item *
+
+Nicholas Perez <nperez@cpan.org>
+
+=item *
+
+Luke Saunders <luke.saunders@gmail.com>
+
+=item *
+
+Alexander Hartmaier <abraxxa@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Luke Saunders, Nicholas Perez, et al..
+This software is copyright (c) 2010 by Luke Saunders, Nicholas Perez, Alexander Hartmaier, et al..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
